****************************************
Projection
****************************************

The module ``ANNarchy.Projection`` defines projections at the population level. A projection is an ensemble of connections (or synapses) between a subset of a population (called the pre-synaptic population) and a subset of another population (the post-synaptic population), with a specific connection type. The pre- and post-synaptic populations may be the same.

Class Projection
===============================

.. autoclass:: ANNarchy.Projection
   :members:
